summaryrefslogtreecommitdiff
path: root/firmware/2lib/include/2return_codes.h
diff options
context:
space:
mode:
Diffstat (limited to 'firmware/2lib/include/2return_codes.h')
-rw-r--r--firmware/2lib/include/2return_codes.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/firmware/2lib/include/2return_codes.h b/firmware/2lib/include/2return_codes.h
index 4abe16a7..49f99358 100644
--- a/firmware/2lib/include/2return_codes.h
+++ b/firmware/2lib/include/2return_codes.h
@@ -728,8 +728,9 @@ enum vb2_return_code {
/* AUXFW peripheral busy. Cannot upgrade firmware at present. */
VB2_ERROR_EX_AUXFW_PERIPHERAL_BUSY,
- /* Error setting vendor data (see: VbExSetVendorData). */
- VB2_ERROR_EX_SET_VENDOR_DATA,
+ /* Error setting vendor data (see: VbExSetVendorData).
+ * Deprecated: functionality removed with legacy UI (b/167643628) */
+ VB2_ERROR_DEPRECATED_EX_SET_VENDOR_DATA,
/* The memory test is running but the output buffer was unchanged. */
VB2_ERROR_EX_DIAG_TEST_RUNNING,